# -*- coding: utf-8 -*-

from IPython.terminal.embed import InteractiveShellEmbed
from traitlets.config import Config


def main():
    c = Config()
    c.InteractiveShell.confirm_exit = False

    ipshell = InteractiveShellEmbed(config=c, banner1='')
    ipshell.extension_manager.load_extension('xalc')
    ipshell()

if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

from transformer import tests, XalcInputTransformer
from formatter import XalcFormatter


def load_ipython_extension(ip):
    transformer = XalcInputTransformer()
    ip.input_transformer_manager.logical_line_transforms.append(transformer)

    formatter = ip.display_formatter.formatters['text/plain']
    formatter.for_type(int, XalcFormatter().format_int)

    print 'xalc loaded.  Examples/tests:'
    for inp, out in tests:
        print ' {:10s} => {:10s}'.format(inp, out)
